@@ -14,7 +14,7 @@ import numpy as np
 import torch
 import torch.distributed as dist
 from PIL import Image
-from torch.utils.data import dataloader, distributed
+from torch.utils.data import Dataset, dataloader, distributed
 
 from ultralytics.cfg import IterableSimpleNamespace
 from ultralytics.data.dataset import GroundingDataset, YOLODataset, YOLOMultiModalDataset
@@ -125,7 +125,7 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
     samples are covered exactly once across all GPUs.
 
     Args:
-        dataset (torch.utils.data.Dataset): Dataset to sample from. Must implement __len__.
+        dataset (Dataset): Dataset to sample from. Must implement __len__.
         num_replicas (int, optional): Number of distributed processes. Defaults to world size.
         batch_size (int, optional): Batch size used by dataloader. Defaults to dataset batch size.
         rank (int, optional): Rank of current process. Defaults to current rank.
@@ -144,7 +144,14 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
         ...         ...
     """
 
-    def __init__(self, dataset, num_replicas=None, batch_size=None, rank=None, shuffle=False):
+    def __init__(
+        self,
+        dataset: Dataset,
+        num_replicas: int | None = None,
+        batch_size: int | None = None,
+        rank: int | None = None,
+        shuffle: bool = False,
+    ) -> None:
         """Initialize the sampler with dataset and distributed training parameters."""
         if num_replicas is None:
             num_replicas = dist.get_world_size() if dist.is_initialized() else 1
@@ -153,7 +160,6 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
         if batch_size is None:
             batch_size = getattr(dataset, "batch_size", 1)
 
-        self.dataset = dataset
         self.num_replicas = num_replicas
         self.batch_size = batch_size
         self.rank = rank
@@ -162,7 +168,7 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
         self.total_size = len(dataset)
         self.num_batches = math.ceil(self.total_size / self.batch_size)
 
-    def _get_rank_indices(self):
+    def _get_rank_indices(self) -> tuple[int, int]:
         """Calculate the start and end sample indices for this rank."""
         # Calculate which batches this rank handles
         batches_per_rank_base = self.num_batches // self.num_replicas
@@ -181,7 +187,7 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
 
         return start_idx, end_idx
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator:
         """Generate indices for this rank's contiguous chunk of the dataset."""
         start_idx, end_idx = self._get_rank_indices()
         indices = list(range(start_idx, end_idx))
@@ -193,12 +199,12 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
 
         return iter(indices)
 
-    def __len__(self):
+    def __len__(self) -> int:
         """Return the number of samples in this rank's chunk."""
         start_idx, end_idx = self._get_rank_indices()
         return end_idx - start_idx
 
-    def set_epoch(self, epoch):
+    def set_epoch(self, epoch: int) -> None:
         """Set the epoch for this sampler to ensure different shuffling patterns across epochs.
 
         Args:
@@ -207,7 +213,7 @@ class ContiguousDistributedSampler(torch.utils.data.Sampler):
         self.epoch = epoch
 
 
-def seed_worker(worker_id: int):
+def seed_worker(worker_id: int) -> None:
     """Set dataloader worker seed for reproducibility across worker processes."""
     worker_seed = torch.initial_seed() % 2**32
     np.random.seed(worker_seed)
@@ -223,7 +229,7 @@ def build_yolo_dataset(
     rect: bool = False,
     stride: int = 32,
     multi_modal: bool = False,
-):
+) -> Dataset:
     """Build and return a YOLO dataset based on configuration parameters."""
     dataset = YOLOMultiModalDataset if multi_modal else YOLODataset
     return dataset(
@@ -254,7 +260,7 @@ def build_grounding(
     rect: bool = False,
     stride: int = 32,
     max_samples: int = 80,
-):
+) -> Dataset:
     """Build and return a GroundingDataset based on configuration parameters."""
     return GroundingDataset(
         img_path=img_path,
@@ -284,7 +290,7 @@ def build_dataloader(
     rank: int = -1,
     drop_last: bool = False,
     pin_memory: bool = True,
-):
+) -> InfiniteDataLoader:
     """Create and return an InfiniteDataLoader or DataLoader for training or validation.
 
     Args:
@@ -331,7 +337,9 @@ def build_dataloader(
     )
 
 
-def check_source(source):
+def check_source(
+    source: str | int | Path | list | tuple | np.ndarray | Image.Image | torch.Tensor,
+) -> tuple[Any, bool, bool, bool, bool, bool]:
     """Check the type of input source and return corresponding flag values.
 
     Args:
@@ -379,11 +387,17 @@ def check_source(source):
     return source, webcam, screenshot, from_img, in_memory, tensor
 
 
-def load_inference_source(source=None, batch: int = 1, vid_stride: int = 1, buffer: bool = False, channels: int = 3):
+def load_inference_source(
+    source: str | int | Path | list | tuple | np.ndarray | Image.Image | torch.Tensor,
+    batch: int = 1,
+    vid_stride: int = 1,
+    buffer: bool = False,
+    channels: int = 3,
+):
     """Load an inference source for object detection and apply necessary transformations.
 
     Args:
-        source (str | Path | torch.Tensor | PIL.Image | np.ndarray, optional): The input source for inference.
+        source (str | Path | list | tuple | torch.Tensor | PIL.Image | np.ndarray): The input source for inference.
         batch (int, optional): Batch size for dataloaders.
         vid_stride (int, optional): The frame interval for video sources.
         buffer (bool, optional): Whether stream frames will be buffered.
