@@ -18,8 +18,7 @@ from ultralytics.utils.checks import check_requirements
 
 
 def bbox_iof(polygon1: np.ndarray, bbox2: np.ndarray, eps: float = 1e-6) -> np.ndarray:
-    """
-    Calculate Intersection over Foreground (IoF) between polygons and bounding boxes.
+    """Calculate Intersection over Foreground (IoF) between polygons and bounding boxes.
 
     Args:
         polygon1 (np.ndarray): Polygon coordinates with shape (N, 8).
@@ -65,15 +64,14 @@ def bbox_iof(polygon1: np.ndarray, bbox2: np.ndarray, eps: float = 1e-6) -> np.n
 
 
 def load_yolo_dota(data_root: str, split: str = "train") -> list[dict[str, Any]]:
-    """
-    Load DOTA dataset annotations and image information.
+    """Load DOTA dataset annotations and image information.
 
     Args:
         data_root (str): Data root directory.
         split (str, optional): The split data set, could be 'train' or 'val'.
 
     Returns:
-        (List[Dict[str, Any]]): List of annotation dictionaries containing image information.
+        (list[dict[str, Any]]): List of annotation dictionaries containing image information.
 
     Notes:
         The directory structure assumed for the DOTA dataset:
@@ -107,18 +105,17 @@ def get_windows(
     im_rate_thr: float = 0.6,
     eps: float = 0.01,
 ) -> np.ndarray:
-    """
-    Get the coordinates of sliding windows for image cropping.
+    """Get the coordinates of sliding windows for image cropping.
 
     Args:
-        im_size (Tuple[int, int]): Original image size, (H, W).
-        crop_sizes (Tuple[int, ...], optional): Crop size of windows.
-        gaps (Tuple[int, ...], optional): Gap between crops.
+        im_size (tuple[int, int]): Original image size, (H, W).
+        crop_sizes (tuple[int, ...], optional): Crop size of windows.
+        gaps (tuple[int, ...], optional): Gap between crops.
         im_rate_thr (float, optional): Threshold of windows areas divided by image areas.
         eps (float, optional): Epsilon value for math operations.
 
     Returns:
-        (np.ndarray): Array of window coordinates with shape (N, 4) where each row is [x_start, y_start, x_stop, y_stop].
+        (np.ndarray): Array of window coordinates of shape (N, 4) where each row is [x_start, y_start, x_stop, y_stop].
     """
     h, w = im_size
     windows = []
@@ -175,13 +172,12 @@ def crop_and_save(
     lb_dir: str,
     allow_background_images: bool = True,
 ) -> None:
-    """
-    Crop images and save new labels for each window.
+    """Crop images and save new labels for each window.
 
     Args:
-        anno (Dict[str, Any]): Annotation dict, including 'filepath', 'label', 'ori_size' as its keys.
+        anno (dict[str, Any]): Annotation dict, including 'filepath', 'label', 'ori_size' as its keys.
         windows (np.ndarray): Array of windows coordinates with shape (N, 4).
-        window_objs (List[np.ndarray]): A list of labels inside each window.
+        window_objs (list[np.ndarray]): A list of labels inside each window.
         im_dir (str): The output directory path of images.
         lb_dir (str): The output directory path of labels.
         allow_background_images (bool, optional): Whether to include background images without labels.
@@ -226,15 +222,14 @@ def split_images_and_labels(
     crop_sizes: tuple[int, ...] = (1024,),
     gaps: tuple[int, ...] = (200,),
 ) -> None:
-    """
-    Split both images and labels for a given dataset split.
+    """Split both images and labels for a given dataset split.
 
     Args:
         data_root (str): Root directory of the dataset.
         save_dir (str): Directory to save the split dataset.
         split (str, optional): The split data set, could be 'train' or 'val'.
-        crop_sizes (Tuple[int, ...], optional): Tuple of crop sizes.
-        gaps (Tuple[int, ...], optional): Tuple of gaps between crops.
+        crop_sizes (tuple[int, ...], optional): Tuple of crop sizes.
+        gaps (tuple[int, ...], optional): Tuple of gaps between crops.
 
     Notes:
         The directory structure assumed for the DOTA dataset:
@@ -265,15 +260,14 @@ def split_images_and_labels(
 def split_trainval(
     data_root: str, save_dir: str, crop_size: int = 1024, gap: int = 200, rates: tuple[float, ...] = (1.0,)
 ) -> None:
-    """
-    Split train and val sets of DOTA dataset with multiple scaling rates.
+    """Split train and val sets of DOTA dataset with multiple scaling rates.
 
     Args:
         data_root (str): Root directory of the dataset.
         save_dir (str): Directory to save the split dataset.
         crop_size (int, optional): Base crop size.
         gap (int, optional): Base gap between crops.
-        rates (Tuple[float, ...], optional): Scaling rates for crop_size and gap.
+        rates (tuple[float, ...], optional): Scaling rates for crop_size and gap.
 
     Notes:
         The directory structure assumed for the DOTA dataset:
@@ -304,15 +298,14 @@ def split_trainval(
 def split_test(
     data_root: str, save_dir: str, crop_size: int = 1024, gap: int = 200, rates: tuple[float, ...] = (1.0,)
 ) -> None:
-    """
-    Split test set of DOTA dataset, labels are not included within this set.
+    """Split test set of DOTA dataset, labels are not included within this set.
 
     Args:
         data_root (str): Root directory of the dataset.
         save_dir (str): Directory to save the split dataset.
         crop_size (int, optional): Base crop size.
         gap (int, optional): Base gap between crops.
-        rates (Tuple[float, ...], optional): Scaling rates for crop_size and gap.
+        rates (tuple[float, ...], optional): Scaling rates for crop_size and gap.
 
     Notes:
         The directory structure assumed for the DOTA dataset:
